@@ -270,7 +270,7 @@ basepath = os.path.expanduser('~/share/bby/')
       Jupyter.notebook.base_url
     );
     const isDev = baseRegRes[1] === 'dev-';
-    const domain = isDev ? 'dev.boyuai.com' : 'boyuai.com';
+    const domain = isDev ? 'dev.boyuai.com' : 'www.boyuai.com';
 
     const userId = Number(baseRegRes[2]);
     const content = Jupyter.notebook.toJSON();
